火星救援 (豆瓣)
Description: 火星救援电影简介和剧情介绍,火星救援影评、图片、预告片、影讯、论坛、在线购票
Keywords: 火星救援,The Martian,火星救援影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.235豆瓣电影Top250

# 火星救援 The Martian (2015)

导演: 雷德利·斯科特
编剧: 德鲁·戈达德 / 安迪·威尔
主演: 马特·达蒙 / 杰西卡·查斯坦 / 克里斯汀·韦格 / 杰夫·丹尼尔斯 / 迈克尔·佩纳 / 凯特·玛拉 / 肖恩·宾 / 塞巴斯蒂安·斯坦 / 唐纳德·格洛弗 / 切瓦特·埃加福 / 阿卡塞尔·亨涅 / 陈数 / 高雄 / 本尼迪克特·黄 / 麦肯兹·戴维斯 / 娜奥米·斯科特 / 丽丽·博尔丹 / 布莱恩·卡斯佩
类型: 剧情 / 科幻 / 冒险
制片国家/地区: 英国 / 美国 / 匈牙利 / 约旦
语言: 英语 / 汉语普通话
上映日期: 2015-11-25(中国大陆) / 2015-10-02(美国)
片长: 142分钟 / 151分钟(加长版)
又名: 火星任务(港) / 绝地救援(台) / 火星人
IMDb: tt3659388
官方小站: 《火星救援》官方小站
豆瓣评分
引用
8.5
683502人评价
5星
39.0%
4星
48.7%
3星
11.5%
2星
0.7%
1星
0.2%
好于 97% 科幻片
好于 96% 冒险片
想看 看过
评价:
推荐

## 火星救援的剧情简介 · · · · · ·

载人航天宇宙飞船阿瑞斯3号成功抵达火星，谁知一场破坏力极其巨大的风暴向宇航员们袭来，阿瑞斯3号被迫中断任务，紧急返航。撤离途中，宇航员马克·沃特尼（马特·达蒙 Matt Damon 饰）被飞船上吹落的零件击中，由于生还希望渺茫，队友们只得匆匆返航，并向世人宣告他已牺牲的事实。出乎意料的是，马克以极低的概率活了下来。他躲进驻火星的航天基地疗伤。下一次火星任务要等到四年后，而基地内的补给仅够他维持31天。短暂的绝望后，马克决定利用有限的食物，在这颗空无一人的星球上种植作物，寻找一线生机。与此同时，地球方面也很快发现马克生还的事实，他们想尽办法部署营救计划。孤军奋战的马克，能否等到救援队伍的到来？
影片改编自安迪·威尔的同名科幻小说。 ©豆瓣

## 火星救援的演职员 · · · · · · ( 全部 42 )

- 雷德利·斯科特 导演
- 马特·达蒙 饰 马克·沃特尼 Mark Watney
- 杰西卡·查斯坦 饰 梅丽莎·刘易斯 Melissa Lewis
- 克里斯汀·韦格 饰 安妮·蒙特罗斯 Annie Montrose
- 杰夫·丹尼尔斯 饰 特迪·桑德斯 Teddy Sanders
- 迈克尔·佩纳 饰 里克·马丁内斯 Rick Martinez

## 火星救援的视频和图片 · · · · · · ( 预告片30 | 添加视频评论 | 图片1299 · 添加 )

## 火星救援的获奖情况 · · · · · · ( 全部 )

- 第88届奥斯卡金像奖
- 最佳影片(提名)
- 雷德利·斯科特 / 马克·赫法姆 / 西蒙·金伯格 / 迈克尔·舍费尔

- 第73届金球奖
- 电影类 最佳音乐/喜剧片

- 第69届英国电影学院奖
- 电影奖 最佳导演(提名)
- 雷德利·斯科特

## 喜欢这部电影的人也喜欢 · · · · · ·

  星际穿越

  黑客帝国

  头号玩家

  阿凡达

  第九区

  变形金刚

  明日边缘

  地心引力

  X战警：逆转未来

  源代码

我要写短评

## 火星救援的短评 · · · · · · ( 全部 156775 条 )

热门 / 最新 / 好友

### 3573 有用 小油飞 看过 2015-10-03 11:23:15

非常喜欢！这些年找一部不洒狗血不煽情的科幻片容易吗。要论科幻气质Ridley Scott比诺兰强太多了。喜剧的外表下是其实是格外正统的硬科幻路数，没有乱七八糟的感情线来喧宾夺主简直太棒。我最喜欢的地方是在求生的过程中完全没有强调对地球的执念，高潮甚至都不是回到地球，因为那完全不重要！

### 621 有用 何倩彤 看过 2015-10-03 01:15:53

並無渲染宇宙的崇高華美，Ridley Scott給過我們一個由性、汗、血、黏液溝成的潮濕太空，現在給我們換一個質樸，沉實，粗礦，禁欲的。從前太空的恐怖在於we are not alone，現在太空的嚴酷在於we are on our own。

### 3131 有用 点金 看过 2015-10-03 12:43:19

本片完美展示了什么叫以逗逼的精神面对惨淡的人生 更加坚定了要做一个有逗逼精神的人 并且在逗逼的道路上找到一个一样具有逗逼精神的人

### 2708 有用 末药煎肉塔 看过 2015-10-03 11:57:00

很好看的太空荒野求生记，马特达蒙一定是找了裸替他不可棱瘦的下来。另外贵国是有多想赚中国市场的钱，看到国家航天局直接笑出声了

### 2257 有用 影志 看过 2015-11-12 13:54:23

孤独如《瓦力》，求生如《荒岛余生》，乐观如《鲁滨逊漂流记》，逃生如《地心引力》…没《星际穿越》那么浩瀚，一个小火星胜似一个宇宙，逗比程度也不及原著一半，更多的是硬科幻和科普纪实。但说实话，连续三年太空科幻题材，或多或少有些疲劳，拍的又如此工整，无惊艳之笔、也绝非神作。

> 更多短评 156775条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 火星救援的影评 · · · · · · ( 全部 1369 条 )

热门 / 最新 / 好友
乌鸦乌鸦 2015-10-05 10:30:47

## 遇到不煽情的电影是高兴还是更高兴

继《大兵瑞恩》、《星际穿越》以后，马特同志又走丢了。我心中暗暗以为这是连戏的，未来人去二战抓来久经考验的瑞恩大兵，完成火星任务后又派他探索宜居行星，因为在火星任务中受到万众瞩目，曼恩博士终于受不了被人类抛弃的心理落差，精神崩溃做出假数据骗人。 这样可以解答三... (展开)
4705 316 291回应 收起
KL 2015-10-06 11:45:01

## 关于《火星救援》你应该知道的25件事+吐槽

（11.25更新） 最新文章：[《侠盗一号》彩蛋全整理] 1. 影片获得了美国宇航局NASA的全力支持。剧本有50页的内容都是有关NASA的细节，力求呈现出的宇航员形象和行动符合实情。影片总共拍摄周期大约是70天，其中拍摄NASA细节的内容花了剧组21天时间。 2. 影片中最开始的火星任务... (展开)
2099 91 202回应 收起
陈灼 2015-10-02 07:27:11

## 一个人就是一个火星

9月30号上午在本地一家电影院看的，因为不是周末，又是白天，人不多，但笑声很多。因为对原著太过熟悉，而所有预告片又刷了好多遍，所以看起来就不会有太多“惊喜”，因为真的是非常忠实原著，连坐在我旁边的老婆，还是大半年前看过我初译稿，也不时跟我会心一笑，因为台词都是... (展开)
1115 153 110回应 收起
猫饼干 2015-10-07 14:00:48

## 这部片适合创业者看！

这篇影评可能有剧透

这部电影，又名《我在火星当农民》，超级适合技术宅尤其是工程师和创业者观看。说它是一部科幻片？不不不，看完了你就发现，这个故事天天都在你身边上演。 剧情简介，大概是这样子的： “我叫马特呆萌，在一个六人团队里做一个创业项目。刚开始我们进行得很顺利，直到突然发生... (展开)
790 42 76回应 收起
perceptor 2015-10-07 01:33:16

## 硬核的科幻、软萌的达蒙和流动的斯科特

这篇影评可能有剧透

从2013年的《地心引力》，2014年的《星际穿越》，到今年的《火星人》，近几年的秋季档总是会为我们带来一部高质量的太空题材硬科幻大片，在票房口碑大丰收之余顺便利用时间上的近水楼台先得月为奥斯卡奖怒刷存在感。 无论是街边用马特达蒙大头铺天盖地的广告，还是视频网站愈... (展开)
506 45 64回应 收起
Melodrame 2015-10-01 08:36:33

## I'm pretty much fucked but not giving up yet

在苏格兰的火车站加一元买了原著，去伦敦将近六个小时的火车上看了一半就对电影期待的不要不要的。好看，符合我对于fiction所有的期待（The Martian is everything you want from a novel）马特呆萌太符合主角Mark Watney的气质，不知道原来他开玩笑也可以那么好笑（没有黑的意... (展开)
468 61 51回应 收起
马泽尔法克尔 2015-10-17 19:07:48

## 老子这么好玩，怎么能随随便便被玩死

这篇影评可能有剧透

道听途说的剧透： 段子手宇航员马特呆萌在火星执行任务时不幸遭遇风暴，身负重伤。作为主角，他当然不会轻易狗带。捡回一条命的呆萌在队友们都逃离火星并以为自己已死的情况下现在可以一个人独占火星基地里六人份的辣条。但是如果他不能尽快跟NASA联系上，那自己早晚还是药丸... (展开)
441 85 67回应 收起
小玄儿 2015-10-15 08:35:04

## 当70年代迪斯科舞曲响彻火星天际——北美新片《火星救援》漫谈

这篇影评可能有剧透

当70年代迪斯科舞曲响彻火星天际 火星是遥远的，距离地球最远超过4亿公里。 火星是寒冷的，夜间温度时为零下70摄氏度。 火星是瑰丽的，因为空气中的尘埃落日呈蓝色。 近期，NASA也只是仅仅在火星表面发现了有液态水活动的证据。这意味着火星表面很可能有液态水活动，但是距离证... (展开)
279 14 84回应 收起
Dr希鲁鲁克 2015-11-29 10:44:46

## 文盲看《火星救援》的感受

对于我这种文盲来讲，观看《火星救援》的过程中充满了刺激的反转。 故事的开头，火星上刮起了沙尘暴，美国探险队被迫提前离开，而马特呆萌不幸被刮飞，就当我以为队员们会手拉手肩并肩找到马特呆萌大声告诉他不抛弃不放弃然后一起高唱团结就是力量的时候。马特呆萌被独自抛弃... (展开)
181 41 32回应 收起
CyberKnight电子骑士 2015-11-27 11:36:22

## 简单不孤单的火星人

这是一个复杂的时代，超级英雄们都不屑于头脑简单地打打杀杀，他们纠结、思考，像陀思妥耶夫斯基小说主人公那样审视自己的心灵，每天不问自己三遍“我是谁，我从哪里来，我要往何处去”就无法脱掉斗篷和战袍上床安睡（一个人！）。岂止超级英雄，几乎所有银幕英雄都越来越苦大... (展开)
193 18 16回应 收起

> 更多影评 1369篇

添加新讨论

## 讨论区 · · · · · ·

中国的元素加入的太生硬，看的尴尬症要犯了 | 来自mr.淡妆 | 38 回应 | 2022-11-22 14:25:17
我就想知道呆萌是怎么靠没调味料的土豆活那么久的 | 来自madaoooo | 8 回应 | 2022-11-14 15:47:35
有个问题 | 来自02 | 1 回应 | 2022-11-06 00:50:04
粪不发酵不能用的 | 来自xiaxiaxia | 8 回应 | 2022-11-04 15:40:10
对土豆有了新的认知 | 来自dc0802 |  | 2022-10-29 23:42:33

> 去这部影片的讨论区（全部130条）

## 关于《火星救援》的问题 · · · · · · ( 全部211个 )

- 看了剧情简介，难道这是《火星任务》的前传吗？ 19人回答
- 為什麼在呆萌開車轉移到隕石坑時再也沒發生過風暴？ 29人回答

> 全部211个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- {北美电影票房总排行} (荔枝超人)
- 数学、物理学生可能感兴趣的电影、纪录片 (傑)
- ★豆瓣高分电影榜★ （中）8.5-8.3分 (影志)
- IMDb科幻电影Top200 (等一个人)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)

## 谁在看这部电影 · · · · · ·

- 解语花
  4分钟前 看过
- 杨坚强
  4分钟前 看过
- 在雨中
  6分钟前 看过

1157747人看过 / 137564人想看

订阅火星救援的评论:
feed: rss 2.0